**chrono-kit** is an open source python library for time series analysis and forecasting.

This project was started in 2023 by ODTU YZT.
## Documentation
See the [wiki](https://github.com/odtuyzt/chrono-kit/wiki) for documentation.

Or take a look at the [examples](https://github.com/odtuyzt/chrono-kit/tree/main/examples).

## Installation

### Dependencies

chronokit requires:

* python >= 3.8.17
* torch >= 1.13.1
* numpy >= 1.22.0
* pandas >= 1.4.0
* scipy >= 1.4.1
* matplotlib >= 3.2.1

### User Installation

    pip install chrono-kit
